# Tree

Django orm trees for postgresql.

Implements as an adjacent tree with materialized path inside.

Easy to swap nodes and rebuild tree. Easy to lookup for a descendants/ancestors et. Made for performance in bulk changes.
